## chains

This folder contains other sub folder for the different types of chains that can be implemented.
In general, these would be wrapped up in a class. There are different folders for this:

- `generic`: Chains are a powerful tool for building complex applications that use natural language processing. Chains are made up of a sequence of modular components, such as PromptTemplates, Models, and Guardrails.
- `index`: Index-Related Chains are a set of tools in LangChain that allow you to interact with indexes. An index is a data structure that allows you to quickly find information in a large dataset. For example, you could use an index to find all the documents that contain a certain word or phrase.
- `custom`: You can build you own chain, which can be a Class with a collection of other chains and tools.